<?php
/**
 * Plugin Name: WP Duplicate Post Cleaner
 * Plugin URI: https://teesharp.com/wp-duplicate-post-cleaner
 * Description: Quickly detect and remove duplicate posts, pages, or WooCommerce products.
 * Version: 1.0.0
 * Author: Teesharp Limited
 * Author URI: https://teesharp.com
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: wp-duplicate-post-cleaner
 * Domain Path: /languages
 * WC requires at least: 3.0.0
 * WC tested up to: 8.2.0
 */

// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

class WP_Duplicate_Post_Cleaner
{

    /**
     * Initialize the plugin
     */
    public function __construct()
    {
        // Add admin menu
        add_action('admin_menu', array($this, 'add_admin_menu'));

        // Register admin scripts
        add_action('admin_enqueue_scripts', array($this, 'register_admin_scripts'));

        // Add AJAX actions
        add_action('wp_ajax_find_duplicates', array($this, 'find_duplicates_callback'));
        add_action('wp_ajax_delete_duplicate', array($this, 'delete_duplicate_callback'));
        add_action('wp_ajax_bulk_delete_duplicates', array($this, 'bulk_delete_duplicates_callback'));
    }

    /**
     * Add plugin menu under Tools
     */
    public function add_admin_menu()
    {
        add_management_page(
            'WP Duplicate Post Cleaner',
            'Duplicate Cleaner',
            'manage_options',
            'wp-duplicate-post-cleaner',
            array($this, 'display_admin_page')
        );
    }

    /**
     * Register admin scripts and styles
     */
    public function register_admin_scripts($hook)
    {
        if ('tools_page_wp-duplicate-post-cleaner' !== $hook) {
            return;
        }

        // Register styles
        wp_enqueue_style(
            'wp-duplicate-post-cleaner-styles',
            plugin_dir_url(__FILE__) . 'admin/css/style.css',
            array(),
            '1.0.0'
        );

        // Register scripts
        wp_enqueue_script(
            'wp-duplicate-post-cleaner-script',
            plugin_dir_url(__FILE__) . 'admin/js/script.js',
            array('jquery'),
            '1.0.0',
            true
        );

        // Localize script with nonce
        wp_localize_script(
            'wp-duplicate-post-cleaner-script',
            'wpdpc_vars',
            array(
                'ajax_url' => admin_url('admin-ajax.php'),
                'nonce' => wp_create_nonce('wpdpc_nonce')
            )
        );
    }

    /**
     * Display the admin page
     */
    public function display_admin_page()
    {
        // Create the admin directory and files if they don't exist
        $this->maybe_create_admin_files();

        // Get post types
        $post_types = get_post_types(array('public' => true), 'objects');
        ?>
        <div class="wrap">
            <h1><?php _e('WP Duplicate Post Cleaner', 'wp-duplicate-post-cleaner'); ?></h1>
            <p><?php _e('Find and remove duplicate content from your WordPress site.', 'wp-duplicate-post-cleaner'); ?></p>

            <div class="wpdpc-container">
                <div class="wpdpc-options">
                    <h2><?php _e('Find Duplicates', 'wp-duplicate-post-cleaner'); ?></h2>
                    <form id="wpdpc-find-form">
                        <div class="wpdpc-option-group">
                            <label for="wpdpc-post-type"><?php _e('Post Type:', 'wp-duplicate-post-cleaner'); ?></label>
                            <select id="wpdpc-post-type" name="post_type">
                                <?php foreach ($post_types as $post_type): ?>
                                    <option value="<?php echo esc_attr($post_type->name); ?>">
                                        <?php echo esc_html($post_type->labels->singular_name); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="wpdpc-option-group">
                            <label
                                for="wpdpc-duplicate-criteria"><?php _e('Find duplicates based on:', 'wp-duplicate-post-cleaner'); ?></label>
                            <select id="wpdpc-duplicate-criteria" name="criteria">
                                <option value="title"><?php _e('Title', 'wp-duplicate-post-cleaner'); ?></option>
                                <option value="content"><?php _e('Content', 'wp-duplicate-post-cleaner'); ?></option>
                                <option value="both"><?php _e('Both Title and Content', 'wp-duplicate-post-cleaner'); ?>
                                </option>
                                <option value="slug"><?php _e('Slug', 'wp-duplicate-post-cleaner'); ?></option>
                                <?php if (class_exists('WooCommerce')): ?>
                                    <option value="sku"><?php _e('SKU (WooCommerce)', 'wp-duplicate-post-cleaner'); ?></option>
                                <?php endif; ?>
                            </select>
                        </div>

                        <div class="wpdpc-option-group">
                            <label for="wpdpc-date-range"><?php _e('Date Range:', 'wp-duplicate-post-cleaner'); ?></label>
                            <select id="wpdpc-date-range" name="date_range">
                                <option value="all"><?php _e('All Time', 'wp-duplicate-post-cleaner'); ?></option>
                                <option value="last_day"><?php _e('Last 24 Hours', 'wp-duplicate-post-cleaner'); ?></option>
                                <option value="last_week"><?php _e('Last 7 Days', 'wp-duplicate-post-cleaner'); ?></option>
                                <option value="last_month"><?php _e('Last 30 Days', 'wp-duplicate-post-cleaner'); ?></option>
                                <option value="last_year"><?php _e('Last Year', 'wp-duplicate-post-cleaner'); ?></option>
                            </select>
                        </div>

                        <div class="wpdpc-option-group">
                            <label for="wpdpc-status"><?php _e('Post Status:', 'wp-duplicate-post-cleaner'); ?></label>
                            <select id="wpdpc-status" name="status">
                                <option value="any"><?php _e('Any', 'wp-duplicate-post-cleaner'); ?></option>
                                <option value="publish"><?php _e('Published', 'wp-duplicate-post-cleaner'); ?></option>
                                <option value="draft"><?php _e('Draft', 'wp-duplicate-post-cleaner'); ?></option>
                                <option value="pending"><?php _e('Pending', 'wp-duplicate-post-cleaner'); ?></option>
                                <option value="trash"><?php _e('Trash', 'wp-duplicate-post-cleaner'); ?></option>
                            </select>
                        </div>

                        <div class="wpdpc-button-container">
                            <button type="submit" class="button button-primary" id="wpdpc-find-button">
                                <?php _e('Find Duplicates', 'wp-duplicate-post-cleaner'); ?>
                            </button>
                            <span class="spinner"></span>
                        </div>
                    </form>
                </div>

                <div class="wpdpc-results">
                    <h2><?php _e('Results', 'wp-duplicate-post-cleaner'); ?></h2>
                    <div id="wpdpc-results-container">
                        <p class="wpdpc-no-results">
                            <?php _e('Use the options on the left to find duplicate content.', 'wp-duplicate-post-cleaner'); ?>
                        </p>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }

    /**
     * Create necessary admin files if they don't exist
     */
    private function maybe_create_admin_files()
    {
        // Create admin directory
        $admin_dir = plugin_dir_path(__FILE__) . 'admin';
        if (!file_exists($admin_dir)) {
            mkdir($admin_dir, 0755, true);
        }

        // Create CSS directory
        $css_dir = $admin_dir . '/css';
        if (!file_exists($css_dir)) {
            mkdir($css_dir, 0755, true);
        }

        // Create JS directory
        $js_dir = $admin_dir . '/js';
        if (!file_exists($js_dir)) {
            mkdir($js_dir, 0755, true);
        }

        // Create CSS file if it doesn't exist
        $css_file = $css_dir . '/style.css';
        if (!file_exists($css_file)) {
            $css_content = "
            .wpdpc-container {
                display: flex;
                margin-top: 20px;
            }
            
            .wpdpc-options {
                flex: 0 0 30%;
                margin-right: 30px;
                background: #fff;
                padding: 20px;
                border-radius: 5px;
                box-shadow: 0 1px 3px rgba(0,0,0,.1);
            }
            
            .wpdpc-results {
                flex: 0 0 65%;
                background: #fff;
                padding: 20px;
                border-radius: 5px;
                box-shadow: 0 1px 3px rgba(0,0,0,.1);
            }
            
            .wpdpc-option-group {
                margin-bottom: 15px;
            }
            
            .wpdpc-option-group label {
                display: block;
                margin-bottom: 5px;
                font-weight: 600;
            }
            
            .wpdpc-option-group select {
                width: 100%;
            }
            
            .wpdpc-button-container {
                margin-top: 20px;
                display: flex;
                align-items: center;
            }
            
            .wpdpc-button-container .spinner {
                margin-left: 10px;
                float: none;
            }
            
            .wpdpc-duplicate-group {
                margin-bottom: 30px;
                border-bottom: 1px solid #eee;
                padding-bottom: 20px;
            }
            
            .wpdpc-duplicate-group:last-child {
                border-bottom: none;
            }
            
            .wpdpc-duplicate-title {
                font-size: 16px;
                font-weight: 600;
                margin-bottom: 10px;
            }
            
            .wpdpc-duplicate-items {
                background: #f9f9f9;
                padding: 10px;
                border-radius: 4px;
                margin-bottom: 10px;
            }
            
            .wpdpc-duplicate-item {
                padding: 10px;
                margin-bottom: 5px;
                border: 1px solid #e5e5e5;
                background: #fff;
                display: flex;
                justify-content: space-between;
                align-items: center;
            }
            
            .wpdpc-duplicate-item:last-child {
                margin-bottom: 0;
            }
            
            .wpdpc-item-info {
                flex: 1;
            }
            
            .wpdpc-item-id {
                color: #777;
                font-size: 12px;
            }
            
            .wpdpc-item-actions {
                margin-left: 15px;
            }
            
            .wpdpc-stats {
                margin-bottom: 20px;
                padding: 15px;
                background: #f0f6fc;
                border-radius: 4px;
            }
            
            .wpdpc-bulk-actions {
                margin-bottom: 20px;
                display: none;
            }
            
            .wpdpc-no-results {
                font-style: italic;
                color: #777;
            }
            
            .wpdpc-view-link {
                margin-right: 10px;
            }
            
            .wpdpc-keep-button {
                background: #4CAF50 !important;
                color: white !important;
                margin-right: 5px !important;
            }
            
            .wpdpc-keep-all-newest,
            .wpdpc-keep-all-oldest {
                margin-right: 10px;
            }
            
            .wpdpc-loader {
                text-align: center;
                padding: 30px;
            }
            ";
            file_put_contents($css_file, $css_content);
        }

        // Create JS file if it doesn't exist
        $js_file = $js_dir . '/script.js';
        if (!file_exists($js_file)) {
            $js_content = "
            jQuery(document).ready(function($) {
                // Find duplicates
                $('#wpdpc-find-form').on('submit', function(e) {
                    e.preventDefault();
                    
                    var form = $(this);
                    var resultsContainer = $('#wpdpc-results-container');
                    var spinner = form.find('.spinner');
                    
                    // Show spinner
                    spinner.addClass('is-active');
                    
                    // Clear previous results
                    resultsContainer.html('<div class=\"wpdpc-loader\">Searching for duplicates...</div>');
                    
                    // Get form data
                    var formData = {
                        action: 'find_duplicates',
                        nonce: wpdpc_vars.nonce,
                        post_type: $('#wpdpc-post-type').val(),
                        criteria: $('#wpdpc-duplicate-criteria').val(),
                        date_range: $('#wpdpc-date-range').val(),
                        status: $('#wpdpc-status').val()
                    };
                    
                    // Send AJAX request
                    $.post(wpdpc_vars.ajax_url, formData, function(response) {
                        // Hide spinner
                        spinner.removeClass('is-active');
                        
                        // Update results container
                        resultsContainer.html(response.data);
                        
                        // Initialize event handlers for the results
                        initResultHandlers();
                    });
                });
                
                // Initialize event handlers for the results
                function initResultHandlers() {
                    // Delete duplicate
                    $('.wpdpc-delete-button').on('click', function(e) {
                        e.preventDefault();
                        
                        if (!confirm('Are you sure you want to delete this item?')) {
                            return;
                        }
                        
                        var button = $(this);
                        var itemId = button.data('id');
                        var item = button.closest('.wpdpc-duplicate-item');
                        
                        // Disable button
                        button.prop('disabled', true).text('Deleting...');
                        
                        // Send AJAX request
                        $.post(wpdpc_vars.ajax_url, {
                            action: 'delete_duplicate',
                            nonce: wpdpc_vars.nonce,
                            post_id: itemId
                        }, function(response) {
                            if (response.success) {
                                // Remove item from list
                                item.fadeOut(300, function() {
                                    $(this).remove();
                                    
                                    // Check if this was the last item in the group
                                    var group = item.closest('.wpdpc-duplicate-group');
                                    var remainingItems = group.find('.wpdpc-duplicate-item').length;
                                    
                                    if (remainingItems <= 1) {
                                        group.fadeOut(300, function() {
                                            $(this).remove();
                                            
                                            // Check if there are no more groups
                                            var totalGroups = $('.wpdpc-duplicate-group').length;
                                            
                                            if (totalGroups === 0) {
                                                $('#wpdpc-results-container').html('<p class=\"wpdpc-no-results\">No duplicates found.</p>');
                                                $('.wpdpc-bulk-actions').hide();
                                                $('.wpdpc-stats').hide();
                                            } else {
                                                // Update stats
                                                updateStats();
                                            }
                                        });
                                    } else {
                                        // Update stats
                                        updateStats();
                                    }
                                });
                            } else {
                                // Enable button
                                button.prop('disabled', false).text('Delete');
                                
                                // Show error
                                alert('Error: ' + response.data);
                            }
                        });
                    });
                    
                    // Keep this item (delete all others in group)
                    $('.wpdpc-keep-button').on('click', function(e) {
                        e.preventDefault();
                        
                        if (!confirm('This will delete ALL OTHER items in this group. Are you sure?')) {
                            return;
                        }
                        
                        var button = $(this);
                        var itemId = button.data('id');
                        var group = button.closest('.wpdpc-duplicate-group');
                        var otherItems = group.find('.wpdpc-duplicate-item').filter(function() {
                            return $(this).find('.wpdpc-delete-button').data('id') != itemId;
                        });
                        
                        // Disable button
                        button.prop('disabled', true).text('Processing...');
                        
                        // Create array of IDs to delete
                        var idsToDelete = [];
                        otherItems.each(function() {
                            idsToDelete.push($(this).find('.wpdpc-delete-button').data('id'));
                        });
                        
                        // Send AJAX request
                        $.post(wpdpc_vars.ajax_url, {
                            action: 'bulk_delete_duplicates',
                            nonce: wpdpc_vars.nonce,
                            post_ids: idsToDelete
                        }, function(response) {
                            if (response.success) {
                                // Remove other items from list
                                otherItems.fadeOut(300, function() {
                                    $(this).remove();
                                    
                                    // Remove the group as there's only one item left
                                    group.fadeOut(300, function() {
                                        $(this).remove();
                                        
                                        // Check if there are no more groups
                                        var totalGroups = $('.wpdpc-duplicate-group').length;
                                        
                                        if (totalGroups === 0) {
                                            $('#wpdpc-results-container').html('<p class=\"wpdpc-no-results\">No duplicates found.</p>');
                                            $('.wpdpc-bulk-actions').hide();
                                            $('.wpdpc-stats').hide();
                                        } else {
                                            // Update stats
                                            updateStats();
                                        }
                                    });
                                });
                            } else {
                                // Enable button
                                button.prop('disabled', false).text('Keep This, Delete Others');
                                
                                // Show error
                                alert('Error: ' + response.data);
                            }
                        });
                    });
                    
                    // Keep all newest posts
                    $('.wpdpc-keep-all-newest').on('click', function(e) {
                        e.preventDefault();
                        
                        if (!confirm('This will delete all older duplicate items, keeping only the newest in each group. Are you sure?')) {
                            return;
                        }
                        
                        var button = $(this);
                        var idsToDelete = [];
                        
                        // Disable button
                        button.prop('disabled', true).text('Processing...');
                        
                        // For each group, keep the newest post
                        $('.wpdpc-duplicate-group').each(function() {
                            var group = $(this);
                            var items = group.find('.wpdpc-duplicate-item');
                            
                            // Sort items by date (newest first)
                            items.sort(function(a, b) {
                                var dateA = new Date($(a).data('date'));
                                var dateB = new Date($(b).data('date'));
                                return dateB - dateA;
                            });
                            
                            // Keep the first item (newest), delete the rest
                            items.each(function(index) {
                                if (index > 0) {
                                    idsToDelete.push($(this).find('.wpdpc-delete-button').data('id'));
                                }
                            });
                        });
                        
                        // If no IDs to delete, return
                        if (idsToDelete.length === 0) {
                            button.prop('disabled', false).text('Keep All Newest');
                            return;
                        }
                        
                        // Send AJAX request
                        $.post(wpdpc_vars.ajax_url, {
                            action: 'bulk_delete_duplicates',
                            nonce: wpdpc_vars.nonce,
                            post_ids: idsToDelete
                        }, function(response) {
                            if (response.success) {
                                // Reload results
                                $('#wpdpc-find-button').click();
                            } else {
                                // Enable button
                                button.prop('disabled', false).text('Keep All Newest');
                                
                                // Show error
                                alert('Error: ' + response.data);
                            }
                        });
                    });
                    
                    // Keep all oldest posts
                    $('.wpdpc-keep-all-oldest').on('click', function(e) {
                        e.preventDefault();
                        
                        if (!confirm('This will delete all newer duplicate items, keeping only the oldest in each group. Are you sure?')) {
                            return;
                        }
                        
                        var button = $(this);
                        var idsToDelete = [];
                        
                        // Disable button
                        button.prop('disabled', true).text('Processing...');
                        
                        // For each group, keep the oldest post
                        $('.wpdpc-duplicate-group').each(function() {
                            var group = $(this);
                            var items = group.find('.wpdpc-duplicate-item');
                            
                            // Sort items by date (oldest first)
                            items.sort(function(a, b) {
                                var dateA = new Date($(a).data('date'));
                                var dateB = new Date($(b).data('date'));
                                return dateA - dateB;
                            });
                            
                            // Keep the first item (oldest), delete the rest
                            items.each(function(index) {
                                if (index > 0) {
                                    idsToDelete.push($(this).find('.wpdpc-delete-button').data('id'));
                                }
                            });
                        });
                        
                        // If no IDs to delete, return
                        if (idsToDelete.length === 0) {
                            button.prop('disabled', false).text('Keep All Oldest');
                            return;
                        }
                        
                        // Send AJAX request
                        $.post(wpdpc_vars.ajax_url, {
                            action: 'bulk_delete_duplicates',
                            nonce: wpdpc_vars.nonce,
                            post_ids: idsToDelete
                        }, function(response) {
                            if (response.success) {
                                // Reload results
                                $('#wpdpc-find-button').click();
                            } else {
                                // Enable button
                                button.prop('disabled', false).text('Keep All Oldest');
                                
                                // Show error
                                alert('Error: ' + response.data);
                            }
                        });
                    });
                }
                
                // Update stats
                function updateStats() {
                    var totalGroups = $('.wpdpc-duplicate-group').length;
                    var totalDuplicates = $('.wpdpc-duplicate-item').length - totalGroups;
                    
                    $('.wpdpc-total-groups').text(totalGroups);
                    $('.wpdpc-total-duplicates').text(totalDuplicates);
                }
            });
            ";
            file_put_contents($js_file, $js_content);
        }
    }

    /**
     * AJAX callback for finding duplicates
     */
    public function find_duplicates_callback()
    {
        // Check nonce
        if (!isset($_POST['nonce']) || !wp_verify_nonce($_POST['nonce'], 'wpdpc_nonce')) {
            wp_send_json_error('Invalid nonce');
        }

        // Check user capabilities
        if (!current_user_can('manage_options')) {
            wp_send_json_error('Insufficient permissions');
        }

        // Get parameters
        $post_type = isset($_POST['post_type']) ? sanitize_text_field($_POST['post_type']) : 'post';
        $criteria = isset($_POST['criteria']) ? sanitize_text_field($_POST['criteria']) : 'title';
        $date_range = isset($_POST['date_range']) ? sanitize_text_field($_POST['date_range']) : 'all';
        $status = isset($_POST['status']) ? sanitize_text_field($_POST['status']) : 'any';

        // Set up query args
        $args = array(
            'post_type' => $post_type,
            'post_status' => $status,
            'posts_per_page' => -1,
            'orderby' => 'date',
            'order' => 'DESC',
            'fields' => 'ids'
        );

        // Apply date range filter
        if ($date_range !== 'all') {
            $args['date_query'] = array();

            switch ($date_range) {
                case 'last_day':
                    $args['date_query'][] = array(
                        'after' => '1 day ago'
                    );
                    break;
                case 'last_week':
                    $args['date_query'][] = array(
                        'after' => '1 week ago'
                    );
                    break;
                case 'last_month':
                    $args['date_query'][] = array(
                        'after' => '1 month ago'
                    );
                    break;
                case 'last_year':
                    $args['date_query'][] = array(
                        'after' => '1 year ago'
                    );
                    break;
            }
        }

        // Get all posts
        $query = new WP_Query($args);
        $post_ids = $query->posts;

        // If no posts found
        if (empty($post_ids)) {
            wp_send_json_success('<p class="wpdpc-no-results">No content found matching your criteria.</p>');
        }

        // Find duplicates
        $duplicates = $this->find_duplicates($post_ids, $criteria, $post_type);

        // If no duplicates found
        if (empty($duplicates)) {
            wp_send_json_success('<p class="wpdpc-no-results">No duplicates found.</p>');
        }

        // Count total duplicates
        $total_groups = count($duplicates);
        $total_duplicates = 0;

        foreach ($duplicates as $group) {
            $total_duplicates += count($group) - 1;
        }

        // Start output
        ob_start();

        // Display stats
        ?>
        <div class="wpdpc-stats">
            <h3><?php _e('Results Summary', 'wp-duplicate-post-cleaner'); ?></h3>
            <p>
                <?php printf(
                    __('Found %s groups of duplicates with a total of %s redundant items.', 'wp-duplicate-post-cleaner'),
                    '<strong class="wpdpc-total-groups">' . $total_groups . '</strong>',
                    '<strong class="wpdpc-total-duplicates">' . $total_duplicates . '</strong>'
                ); ?>
            </p>
        </div>

        <div class="wpdpc-bulk-actions" style="display: block;">
            <h3><?php _e('Bulk Actions', 'wp-duplicate-post-cleaner'); ?></h3>
            <button class="button wpdpc-keep-all-newest">
                <?php _e('Keep All Newest', 'wp-duplicate-post-cleaner'); ?>
            </button>
            <button class="button wpdpc-keep-all-oldest">
                <?php _e('Keep All Oldest', 'wp-duplicate-post-cleaner'); ?>
            </button>
        </div>

        <?php
        // Display duplicate groups
        foreach ($duplicates as $key => $group) {
            $first_post = get_post($group[0]);
            $duplicate_key = '';

            switch ($criteria) {
                case 'title':
                    $duplicate_key = $first_post->post_title;
                    break;
                case 'content':
                    $duplicate_key = wp_trim_words($first_post->post_content, 10);
                    break;
                case 'both':
                    $duplicate_key = $first_post->post_title;
                    break;
                case 'slug':
                    $duplicate_key = $first_post->post_name;
                    break;
                case 'sku':
                    $duplicate_key = get_post_meta($first_post->ID, '_sku', true);
                    break;
            }

            ?>
            <div class="wpdpc-duplicate-group">
                <div class="wpdpc-duplicate-title">
                    <?php printf(
                        __('Group #%s: %s', 'wp-duplicate-post-cleaner'),
                        $key + 1,
                        esc_html($duplicate_key)
                    ); ?>
                </div>

                <div class="wpdpc-duplicate-items">
                    <?php foreach ($group as $post_id):
                        $post = get_post($post_id);
                        $edit_link = get_edit_post_link($post_id);
                        $view_link = get_permalink($post_id);
                        $post_date = get_the_date('Y-m-d H:i:s', $post_id);
                        $author = get_the_author_meta('display_name', $post->post_author);

                        // Get additional info for WooCommerce products
                        $sku = '';
                        if ($post_type === 'product' && class_exists('WooCommerce')) {
                            $sku = get_post_meta($post_id, '_sku', true);
                        }
                        ?>
                        <div class="wpdpc-duplicate-item" data-date="<?php echo esc_attr($post);
                        ?>">
                            <div class="wpdpc-item
                                -info">
                                <strong><?php echo esc_html($post->post_title); ?></strong>
                                <p class="wpdpc-item
                                    -id"><?php echo esc_html($post->ID); ?></p>
                                <p><?php echo esc_html($post->post_type); ?></p>
                                <p><?php echo esc_html($post_date); ?></p>
                                <p><?php echo esc_html($author); ?></p>
                                <?php if (!empty($sku)): ?>
                                    <p><?php echo esc_html($sku); ?></p>
                                <?php endif; ?>
                            </div>
                            <div class="wpdpc-item
                                -actions">
                                <a href="<?php echo esc_url($view_link); ?>" class="button button-small wpdpc-view-link"
                                    target="_blank"><?php _e('View', 'wp-duplicate-post-cleaner'); ?></a>
                                <a href="<?php echo esc_url($edit_link); ?>" class="button button-small"
                                    target="_blank"><?php _e('Edit', 'wp-duplicate-post-cleaner'); ?></a>
                                <button class="button button-small button-primary wpdpc-delete-button"
                                    data-id="<?php echo esc_attr($post->ID); ?>"><?php _e('Delete', 'wp-duplicate-post-cleaner'); ?></button>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
            <?php
        }

        // End output
        $output = ob_get_clean();

        // Send response
        wp_send_json_success($output);
    }

    /**
     * AJAX callback for deleting a duplicate
     */


    public function delete_duplicate_callback()
    {
        // Check nonce
        if (!isset($_POST['nonce']) || !wp_verify_nonce($_POST['nonce'], 'wpdpc_nonce')) {
            wp_send_json_error('Invalid nonce');
        }

        // Check user capabilities
        if (!current_user_can('manage_options')) {
            wp_send_json_error('Insufficient permissions');
        }

        // Get post ID
        $post_id = isset($_POST['post_id']) ? intval($_POST['post_id']) : 0;

        // Check if post exists
        if (!get_post($post_id)) {
            wp_send_json_error('Post not found');
        }

        // Delete post
        $result = wp_delete_post($post_id, true);

        // Send response
        if ($result) {
            wp_send_json_success();
        } else {
            wp_send_json_error('Error deleting post');
        }
    }


    /**
     * AJAX callback for bulk deleting duplicates
     */
    public function bulk_delete_duplicates_callback()
    {
        // Check nonce
        if (!isset($_POST['nonce']) || !wp_verify_nonce($_POST['nonce'], 'wpdpc_nonce')) {
            wp_send_json_error('Invalid nonce');
        }

        // Check user capabilities
        if (!current_user_can('manage_options')) {
            wp_send_json_error('Insufficient permissions');
        }

        // Get post IDs
        $post_ids = isset($_POST['post_ids']) ? $_POST['post_ids'] : array();

        // Check if post IDs are provided
        if (empty($post_ids)) {
            wp_send_json_error('No post IDs provided');
        }

        // Delete posts
        $errors = array();

        foreach ($post_ids as $post_id) {
            $result = wp_delete_post($post_id, true);

            if (!$result) {
                $errors[] = 'Error deleting post ID ' . $post_id;
            }
        }

        // Send response
        if (empty($errors)) {
            wp_send_json_success();
        } else {
            wp_send_json_error(implode(', ', $errors));
        }
    }

    /**
     * Find duplicates based on criteria
     *
     * @param array $post_ids The post IDs to check
     * @param string $criteria The criteria to check for duplicates
     * @param string $post_type The post type
     * @return array An array of duplicate post IDs
     */
    private function find_duplicates($post_ids, $criteria, $post_type)
    {
        $duplicates = array();

        foreach ($post_ids as $post_id) {
            $post = get_post($post_id);
            $key = '';

            switch ($criteria) {
                case 'title':
                    $key = $post->post_title;
                    break;
                case 'content':
                    $key = wp_trim_words($post->post_content, 10);
                    break;
                case 'both':
                    $key = $post->post_title;
                    break;
                case 'slug':
                    $key = $post->post_name;
                    break;
                case 'sku':
                    $key = get_post_meta($post_id, '_sku', true);
                    break;
            }

            $duplicates[$key][] = $post_id;
        }

        // Remove groups with only one item
        foreach ($duplicates as $key => $group) {
            if (count($group) === 1) {
                unset($duplicates[$key]);
            }
        }

        return $duplicates;
    }
}